==> cyphesis-snapshot-1999.01.15.tar.gz: cyphesis/wtime.py <==
""" wtime.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

from DateTime import *
import const

#rule: time->importance       : spring -> seasonal activity
#mind: time2num[a.time]==time : spring -> 3,4,5
#      importance comparison  : 


time_info={'always': [range(1,13),'seasonal'],
           'spring': [[3,4,5],'seasonal'],
           'summer': [[6,7,8],'seasonal'],
           'autumn': [[9,10,11],'seasonal'],
           'winter': [[12,1,2],'seasonal'],
           'morning': [[8], 'daily'],
           'midday': [[12], 'daily'],
           'evening': [[20], 'daily'],
           'night': [[21,22,23,24,0,1,2,3,4,5,6,7], 'daily'],
           'now': [range(25), 'daily']}

importance2num={None: 0,
                'seasonal': 1,
                'daily': 2}

def time2type(t):
    return time_info[t][1]

time2importance=time2type

def cmp_importance(a,b):
    return importance2num[a]-importance2num[b]

def minutes(n): return n*60.0
def hours(n): return minutes(60)*n
def days(n): return hours(24)*n
def months(n): return days(30)*n
def years(n): return months(12)*n

#time functions for world
class world_time:
    time=Date(612)
    stepseconds=const.stepseconds
    stepsize=RelativeDateTime(seconds=+stepseconds)
    def __call__(self):
        return self.time
    def __str__(self):
        s="time="+str(self.time)
        return s
    def __cmp__(self,other):
        if time2type(other)=='seasonal':
            if self.time.month in time_info[other][0]:
                return 0
            else:
                return 1
        if time2type(other)=='daily':
            if self.time.hour in time_info[other][0]:
                return 0
            else:
                return 1
        return 1
    def step(self):
        self.time=self.time+self.stepsize

==> cyphesis-snapshot-1999.02.13.tar.gz: cyphesis/wtime.py <==
""" wtime.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

from DateTime import *
import const

#rule: time->importance       : spring -> seasonal activity
#mind: time2num[a.time]==time : spring -> 3,4,5
#      importance comparison  : 


time_info={'always': [range(1,13),'seasonal'],
           'spring': [[3,4,5],'seasonal'],
           'summer': [[6,7,8],'seasonal'],
           'autumn': [[9,10,11],'seasonal'],
           'winter': [[12,1,2],'seasonal'],
           'morning': [[8], 'daily'],
           'midday': [[12], 'daily'],
           'evening': [[20], 'daily'],
           'night': [[21,22,23,24,0,1,2,3,4,5,6,7], 'daily'],
           'now': [range(25), 'daily']}

importance2num={None: 0,
                'seasonal': 1,
                'daily': 2}

def time2type(t):
    return time_info[t][1]

time2importance=time2type

def cmp_importance(a,b):
    return importance2num[a]-importance2num[b]

def minutes(n): return n*60.0
def hours(n): return minutes(60)*n
def days(n): return hours(24)*n
def months(n): return days(30)*n
def years(n): return months(12)*n

#time functions for world
class world_time:
    def __init__(self):
        self.time=Date(612)
        self.stepseconds=const.stepseconds
        self.stepsize=RelativeDateTime(seconds=+self.stepseconds)
    def __call__(self):
        return self.time
    def __repr__(self):
        return `self.time.tuple()`
    def __str__(self):
        s="time="+str(self.time)
        return s
    def __cmp__(self,other):
        if time2type(other)=='seasonal':
            if self.time.month in time_info[other][0]:
                return 0
            else:
                return 1
        if time2type(other)=='daily':
            if self.time.hour in time_info[other][0]:
                return 0
            else:
                return 1
        return 1
    def mktime(self, *tuple):
        self.time=apply(mktime,tuple)
        return self
    def step(self):
        self.time=self.time+self.stepsize
